# -*- coding: utf-8 -*-
# -*- Python Version: 3.7 -*-

"""Equivalence map between PHPP-space-type-names and Code-space-type-names."""

# -- TABLE C405.3.2(1) INTERIOR LIGHTING POWER ALLOWANCES: BUILDING AREA METHOD
# -- PHPP-Space-Type-Name : Code-Space-Type-Name
space_type_map = {
    "SINGLE OFFICE": "OFFICE",
    "GROUP OFFICE": "OFFICE",
    "OPEN-PLAN OFFICE": "OFFICE",
    "MEETING": "OFFICE",
    "COUNTER AREA": "RETAIL",
    "RETAIL": "RETAIL",
    "RETAIL/DEPARTMENT STORE WITH REFRIGERATED PRODUCTS": "RETAIL",
    "CLASSROOM": "SCHOOL/UNIVERSITY",
    "UNIVERSITY AUDITORIUM": "SCHOOL/UNIVERSITY",
    "BEDROOM": "DORMITORY",
    "HOTEL ROOM": "HOTEL/MOTEL",
    "CANTEEN": "DINING: CAFETERIA/FAST FOOD",
    "RESTAURANT": "DINING: FAMILY",
    "KITCHEN IN NON-RESIDENTIAL BUILDING": "DINING: FAMILY",
    "KITCHEN, STORAGE, PREPARATION": "DINING: FAMILY",
    "WC, SANITARY": "OFFICE",
    "OTHER HABITABLE ROOMS": "OFFICE",
    "SECONDARY AREAS": "OFFICE",
    "CIRCULATION AREA": "OFFICE",
    "STORAGE, SERVICES": "OFFICE",
    "SERVER ROOM": "OFFICE",
    "WORKSHOP (STANDING ACTIVITY)": "WORKSHOP",
    "WORKSHOP (PREDOMINANTLY STANDING ACTIVITY)": "WORKSHOP",
    "WORKSHOP (PREDOMINANTLY SEDENTARY ACTIVITY)": "WORKSHOP",
    "THEATRE AUDITORIUM": "PERFORMING ARTS THEATER",
    "THEATRE FOYER": "PERFORMING ARTS THEATER",
    "THEATRE STAGE": "PERFORMING ARTS THEATER",
    "FAIR, CONGRESS": "COURTHOUSE",
    "EXHIBITION": "MUSEUM",
    "LIBRARY READING ROOM": "LIBRARY",
    "OPEN ACCESS LIBRARY": "LIBRARY",
    "LIBRARY REPOSITORY": "LIBRARY",
    "SPORTS HALL": "SPORTS ARENA",
    "PARKING GARAGE": "PARKING GARAGE",
    "PUBLIC PARKING GARAGE": "PARKING GARAGE",
    "SAUNA AREA": "EXERCISE CENTER",
    "EXERCISE ROOM": "EXERCISE CENTER",
    "LABORATORY": "HEALTH CARE CLINIC",
    "EXAMINATION/TREATMENT ROOMS": "HEALTH CARE CLINIC",
    "SPECIAL CARE AREAS": "HEALTH CARE CLINIC",
    "CORRIDORS OF THE GENERAL CARE AREA": "HEALTH CARE CLINIC",
    "MEDICAL/THERAPEUTIC PRACTICES": "HEALTH CARE CLINIC",
    "WAREHOUSES": "WAREHOUSE",
}
